@@ -634,7 +634,7 @@ ggResult <- quadFuncEst( "invest", c( "value", "capital" ), ggData )
 coef( ggResult )
 print( ggResult )
 round( fitted( ggResult ), 2 )
-round( predict( ggResult ), 2 )
+unname( round( predict( ggResult ), 2 ) )
 all.equal( predict( ggResult ),
    fitted( ggResult ), check.attributes = FALSE )
 round( predict( ggResult, newdata = ggData ), 2 )
@@ -649,7 +649,7 @@ ggResultRan <- quadFuncEst( "invest", c( "value", "capital" ), ggData,
 coef( ggResultRan )
 print( ggResultRan )
 round( fitted( ggResultRan ), 2 )
-round( predict( ggResultRan ), 2 )
+unname( round( predict( ggResultRan ), 2 ) )
 all.equal( predict( ggResultRan ),
    fitted( ggResultRan ), check.attributes = FALSE )
 round( predict( ggResultRan, newdata = ggData ), 2 )
@@ -667,7 +667,7 @@ ggResShifter <- quadFuncEst( "invest", c( "value", "capital" ), ggData,
 coef( ggResShifter )
 printQuadFuncEst( ggResShifter )
 round( fitted( ggResShifter ), 2 )
-round( predict( ggResShifter ), 2 )
+unname( round( predict( ggResShifter ), 2 ) )
 all.equal( predict( ggResShifter ),
    fitted( ggResShifter ), check.attributes = FALSE )
 round( predict( ggResShifter, newdata = ggData ), 2 )
@@ -682,7 +682,7 @@ ggResShifterRan <- quadFuncEst( "invest", c( "value", "capital" ), ggData,
 coef( ggResShifterRan )
 printQuadFuncEst( ggResShifterRan )
 round( fitted( ggResShifterRan ), 2 )
-round( predict( ggResShifterRan ), 2 )
+unname( round( predict( ggResShifterRan ), 2 ) )
 all.equal( predict( ggResShifterRan ),
    fitted( ggResShifterRan ), check.attributes = FALSE )
 round( predict( ggResShifterRan, newdata = ggData ), 2 )
@@ -699,7 +699,7 @@ ggResShifterLogi <- quadFuncEst( "invest", c( "value", "capital" ), ggData,
 coef( ggResShifterLogi )
 printQuadFuncEst( ggResShifterLogi )
 round( fitted( ggResShifterLogi ), 2 )
-round( predict( ggResShifterLogi ), 2 )
+unname( round( predict( ggResShifterLogi ), 2 ) )
 all.equal( predict( ggResShifterLogi ),
    fitted( ggResShifterLogi ), check.attributes = FALSE )
 round( predict( ggResShifterLogi, newdata = ggData ), 2 )
@@ -714,7 +714,7 @@ ggResShifterLogiRan <- quadFuncEst( "invest", c( "value", "capital" ), ggData,
 coef( ggResShifterLogiRan )
 printQuadFuncEst( ggResShifterLogiRan )
 round( fitted( ggResShifterLogiRan ), 2 )
-round( predict( ggResShifterLogiRan ), 2 )
+unname( round( predict( ggResShifterLogiRan ), 2 ) )
 all.equal( predict( ggResShifterLogiRan ),
    fitted( ggResShifterLogiRan ), check.attributes = FALSE )
 round( predict( ggResShifterLogiRan, newdata = ggData ), 2 )
@@ -732,7 +732,7 @@ ggResShifterFac <- quadFuncEst( "invest", c( "value", "capital" ), ggData,
 coef( ggResShifterFac )
 printQuadFuncEst( ggResShifterFac )
 round( fitted( ggResShifterFac ), 2 )
-round( predict( ggResShifterFac ), 2 )
+unname( round( predict( ggResShifterFac ), 2 ) )
 all.equal( predict( ggResShifterFac ),
    fitted( ggResShifterFac ), check.attributes = FALSE )
 round( predict( ggResShifterFac, newdata = ggData ), 2 )
@@ -747,7 +747,7 @@ ggResShifterFacRan <- quadFuncEst( "invest", c( "value", "capital" ), ggData,
 coef( ggResShifterFacRan )
 printQuadFuncEst( ggResShifterFacRan )
 round( fitted( ggResShifterFacRan ), 2 )
-round( predict( ggResShifterFacRan ), 2 )
+unname( round( predict( ggResShifterFacRan ), 2 ) )
 all.equal( predict( ggResShifterFacRan ),
    fitted( ggResShifterFacRan ), check.attributes = FALSE )
 round( predict( ggResShifterFacRan, newdata = ggData ), 2 )
@@ -764,7 +764,7 @@ coef( ggResultLin )
 vcov( ggResultLin )
 print( ggResultLin )
 round( fitted( ggResultLin ), 2 )
-round( predict( ggResultLin ), 2 )
+unname( round( predict( ggResultLin ), 2 ) )
 all.equal( predict( ggResultLin ),
    fitted( ggResultLin ), check.attributes = FALSE )
 round( predict( ggResultLin, newdata = ggData ), 2 )
@@ -779,7 +779,7 @@ coef( ggResultLinRan )
 vcov( ggResultLinRan )
 print( ggResultLinRan )
 round( fitted( ggResultLinRan ), 2 )
-round( predict( ggResultLinRan ), 2 )
+unname( round( predict( ggResultLinRan ), 2 ) )
 all.equal( predict( ggResultLinRan ),
    fitted( ggResultLinRan ), check.attributes = FALSE )
 round( predict( ggResultLinRan, newdata = ggData ), 2 )
